
New trezor test vectors:

tsx_t_uns_01  - 1utxo to simple address
tsx_t_uns_02  - 1utxo to sub address
tsx_t_uns_03  - 1utxo to 2 normal addresses
tsx_t_uns_04  - 1utxo to 1 sub, 1 normal addresses

tsx_t_uns_05  - 2utxo to 3 normal addresses
tsx_t_uns_06  - 2utxo to 1 normal address
tsx_t_uns_07  - 2utxo to 1 sub address
tsx_t_uns_08  - 4utxo to 1 sub, 2 normal addresses
tsx_t_uns_09  - 11utxo to 1 sub, 2 normal addresses
tsx_t_uns_10  - 17utxo to 1 sub, 2 normal addresses

tsx_t_uns_11  - 21utxo to 1 normal address

tsx_t_uns_12  - 3 utxo to 1 normal address + payment id
tsx_t_uns_13  - 1 utxo to 1 sub address + payment id
tsx_t_uns_14  - 1 utxo to 1 normal address + payment id
tsx_t_uns_15  - 16 utxo to 1 normal address + payment id


